==> digikam-3.0.0-rc.tar.bz2: digikam-3.0.0-rc/extra/kipi-plugins/sendimages/kipiplugin_sendimages.desktop.cmake <==
[Desktop Entry]
Name=SendImages
Name[ast]=SendImages
Name[bg]=Изпращане на изображения
Name[ca]=SendImages
Name[ca@valencia]=SendImages
Name[cs]=Odeslání obrázků
Name[da]=SendImages
Name[de]=Bilder senden
Name[el]=SendImages
Name[en_GB]=SendImages
Name[es]=Enviar imágenes
Name[et]=Piltide saatmine
Name[eu]=Bidali irudiak
Name[fi]=Sähköpostilähetys
Name[fr]=SendImages
Name[ga]=SeolÍomhánna
Name[gl]=SendImages
Name[he]=שלח תמונות
Name[hne]=सेंड-इमेज
Name[hu]=Képek küldése
Name[is]=SendaMyndir
Name[it]=Invia immagini
Name[ja]=SendImages
Name[km]=ផ្ញើ​រូបភាព
Name[ko]=SendImages
Name[lv]=Sūtīt attēlus
Name[nb]=Send bilder
Name[nds]=Biller loosstüern
Name[nl]=AfbeeldingenVerzenden
Name[pa]=ਚਿੱਤਰ ਭੇਜੋ
Name[pl]=WyślijObrazy
Name[pt]=Envio de Imagens
Name[pt_BR]=Enviar imagens
Name[ro]=Trimitere imagini
Name[ru]=Отправка изображений
Name[sk]=Poslať obrázky
Name[sl]=SendImages
Name[sq]=SendImages
Name[sv]=Skicka bilder
Name[th]=ส่งภาพทางเมล
Name[tr]=Resim Gönder
Name[uk]=SendImages
Name[x-test]=xxSendImagesxx
Name[zh_CN]=发送图像
Name[zh_TW]=郵寄影像
Comment=A tool to send images by e-mail
Comment[ast]=Una ferramienta pa unviar imáxenes per corréu electrónicu
Comment[bg]=Инструмент за изпращане на изображения по е-поща
Comment[ca]=Una eina per a enviar imatges per correu electrònic
Comment[ca@valencia]=Una eina per a enviar imatges per correu electrònic
Comment[cs]=Nástroj pro odeslání obrázků e-mailem
Comment[da]=Et værktøj til at sende billeder med e-mail
Comment[de]=Ein Werkzeug, um Bilder per E-Mail zu senden.
Comment[el]=Εργαλείο αποστολής εικόνων μέσω ηλ. ταχυδρομείου
Comment[en_GB]=A tool to send images by e-mail
Comment[es]=Una herramienta para el envío de imágenes por correo
Comment[et]=Tööriist piltide saatmiseks e-postiga
Comment[eu]=Irudiak posta elektronikoz bidaltzeko tresna
Comment[fi]=Kuvien lähetys sähköpostitse
Comment[fr]=Outil d'envoi par courrier électronique
Comment[ga]=Uirlis a sheolann íomhánna trí ríomhphost
Comment[gl]=Unha ferramenta para enviar imaxes por correo electrónico
Comment[he]=כלי לשליחת תמונות בדואר אלקטרוני
Comment[hne]=फोटू ल ईमेल से भेजे के एक औजार
Comment[hu]=Egy eszköz képek e-mailben való küldéséhez
Comment[is]=Verkfæri til að senda myndir með tölvupósti
Comment[it]=Uno strumento per inviare immagini per posta elettronica
Comment[ja]=画像をメールで送信するツール
Comment[km]=ឧបករណ៍​ត្រូវ​ផ្ញើ​រូបភាព​តាម​អ៊ីមែល
Comment[lv]=Rīks attēlu nosūtīšanai pa e-pastu
Comment[nb]=Et verktøy for å sende bilder med e-post
Comment[nds]=En Warktüüch, mit dat sik Biller per Nettpost loosstüern laat
Comment[nl]=Een hulpmiddel voor het verzenden van afbeeldingen per e-mail
Comment[pa]=ਈਮੇਲ ਰਾਹੀਂ ਚਿੱਤਰ ਭੇਜਣ ਵਾਸਤੇ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do przesyłania obrazów przez e-maila
Comment[pt]=Uma ferramenta para enviar imagens por e-mail
Comment[pt_BR]=Uma ferramenta para enviar imagens por e-mail
Comment[ro]=O unealtă de trimis imagini prin e-mail
Comment[ru]=Инструмент для отправки изображений по электронной почте
Comment[sk]=Nástroj na posielanie obrázkov cez e-mail
Comment[sl]=Orodje za pošiljanje slik po e-pošti
Comment[sq]=Një mjet për të dërguar imazhet me e-mail
Comment[sv]=Ett verktyg för att skicka bilder via e-post
Comment[th]=เครื่องมือในการส่งภาพต่าง ๆ ทางอีเมล
Comment[tr]=Dosyaları e-posta ile göndermek için bir araç
Comment[uk]=Інструмент для надсилання зображень електронною поштою
Comment[x-test]=xxA tool to send images by e-mailxx
Comment[zh_CN]=一个通过电子邮件发送图像的工具
Comment[zh_TW]=用電子信箱郵寄影像的工具
ServiceTypes=KIPI/Plugin
Type=Service
Icon=mail-send
X-KDE-Library=kipiplugin_sendimages
author=Gilles Caulier, caulier dot gilles at gmail dot com
X-KIPI-MergeMenu=true
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-PluginCategories=Export

==> digikam_3.5.0.orig.tar.bz2: digikam-3.5.0/extra/kipi-plugins/sendimages/kipiplugin_sendimages.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=SendImages
Name=SendImages
Name[ast]=SendImages
Name[bg]=Изпращане на изображения
Name[bs]=Pošalji slike
Name[ca]=SendImages
Name[ca@valencia]=SendImages
Name[cs]=Odeslání obrázků
Name[da]=SendImages
Name[de]=Bilder senden
Name[el]=SendImages
Name[en_GB]=SendImages
Name[es]=Enviar imágenes
Name[et]=Piltide saatmine
Name[eu]=Bidali irudiak
Name[fi]=Sähköpostilähetys
Name[fr]=SendImages
Name[ga]=SeolÍomhánna
Name[gl]=SendImages
Name[he]=שלח תמונות
Name[hne]=सेंड-इमेज
Name[hu]=Képek küldése
Name[is]=SendaMyndir
Name[it]=Invia immagini
Name[ja]=SendImages
Name[km]=ផ្ញើ​រូបភាព
Name[ko]=SendImages
Name[lv]=Sūtīt attēlus
Name[nb]=Send bilder
Name[nds]=Biller loosstüern
Name[nl]=AfbeeldingenVerzenden
Name[pa]=ਚਿੱਤਰ ਭੇਜੋ
Name[pl]=WyślijObrazy
Name[pt]=Envio de Imagens
Name[pt_BR]=Enviar imagens
Name[ro]=Trimitere imagini
Name[ru]=Отправка изображений
Name[sk]=Poslať obrázky
Name[sl]=SendImages
Name[sq]=SendImages
Name[sv]=Skicka bilder
Name[th]=ส่งภาพทางเมล
Name[tr]=Resim Gönder
Name[uk]=SendImages
Name[x-test]=xxSendImagesxx
Name[zh_CN]=发送图像
Name[zh_TW]=郵寄影像
Comment=A tool to send images by e-mail
Comment[ast]=Una ferramienta pa unviar imáxenes per corréu electrónicu
Comment[bg]=Инструмент за изпращане на изображения по е-поща
Comment[bs]=Alat za slanje slika putem e-pošte
Comment[ca]=Una eina per a enviar imatges per correu electrònic
Comment[ca@valencia]=Una eina per a enviar imatges per correu electrònic
Comment[cs]=Nástroj pro odeslání obrázků e-mailem
Comment[da]=Et værktøj til at sende billeder med e-mail
Comment[de]=Ein Werkzeug, um Bilder per E-Mail zu senden.
Comment[el]=Εργαλείο αποστολής εικόνων μέσω ηλ. ταχυδρομείου
Comment[en_GB]=A tool to send images by e-mail
Comment[es]=Una herramienta para el envío de imágenes por correo
Comment[et]=Tööriist piltide saatmiseks e-postiga
Comment[eu]=Irudiak posta elektronikoz bidaltzeko tresna
Comment[fi]=Kuvien lähetys sähköpostitse
Comment[fr]=Un outil d'envoi d'images par courrier électronique
Comment[ga]=Uirlis a sheolann íomhánna trí ríomhphost
Comment[gl]=Unha ferramenta para enviar imaxes por correo electrónico
Comment[he]=כלי לשליחת תמונות בדואר אלקטרוני
Comment[hne]=फोटू ल ईमेल से भेजे के एक औजार
Comment[hu]=Egy eszköz képek e-mailben való küldéséhez
Comment[is]=Verkfæri til að senda myndir með tölvupósti
Comment[it]=Uno strumento per inviare immagini per posta elettronica
Comment[ja]=画像をメールで送信するツール
Comment[km]=ឧបករណ៍​ត្រូវ​ផ្ញើ​រូបភាព​តាម​អ៊ីមែល
Comment[lv]=Rīks attēlu nosūtīšanai pa e-pastu
Comment[nb]=Et verktøy for å sende bilder med e-post
Comment[nds]=En Warktüüch, mit dat sik Biller per Nettpost loosstüern laat
Comment[nl]=Een hulpmiddel voor het verzenden van afbeeldingen per e-mail
Comment[pa]=ਈਮੇਲ ਰਾਹੀਂ ਚਿੱਤਰ ਭੇਜਣ ਵਾਸਤੇ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do przesyłania obrazów przez e-maila
Comment[pt]=Uma ferramenta para enviar imagens por e-mail
Comment[pt_BR]=Uma ferramenta para enviar imagens por e-mail
Comment[ro]=O unealtă de trimis imagini prin e-mail
Comment[ru]=Инструмент для отправки изображений по электронной почте
Comment[sk]=Nástroj na posielanie obrázkov cez e-mail
Comment[sl]=Orodje za pošiljanje slik po e-pošti
Comment[sq]=Një mjet për të dërguar imazhet me e-mail
Comment[sv]=Ett verktyg för att skicka bilder via e-post
Comment[th]=เครื่องมือในการส่งภาพต่าง ๆ ทางอีเมล
Comment[tr]=Dosyaları e-posta ile göndermek için bir araç
Comment[uk]=Інструмент для надсилання зображень електронною поштою
Comment[x-test]=xxA tool to send images by e-mailxx
Comment[zh_CN]=一个通过电子邮件发送图像的工具
Comment[zh_TW]=用電子信箱郵寄影像的工具
ServiceTypes=KIPI/Plugin
Type=Service
Icon=mail-send
X-KDE-Library=kipiplugin_sendimages
author=Gilles Caulier, caulier dot gilles at gmail dot com
X-KIPI-MergeMenu=true
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-PluginCategories=Export
